import { ResultAsync } from "neverthrow";
import { FunctionKeys } from "utility-types";
import { EarnedReward, LinkedAccount, MarketplaceListing, PagedResponse, PagingRequest, PossibleReward, SiteVisit, TokenAddress, TokenBalance, TokenInfo, TokenMarketData, WalletNFT, QueryStatus } from "../businessObjects/index.js";
import { EChain, ECoreProxyType, EInvitationStatus, EWalletDataType } from "../enum/index.js";
import { ProxyError } from "../errors/index.js";
import { IConsentCapacity } from "../interfaces/IConsentCapacity.js";
import { IOpenSeaMetadata } from "../interfaces/IOpenSeaMetadata.js";
import { IScamFilterPreferences } from "../interfaces/IScamFilterPreferences.js";
import { ICoreDiscordMethods, ICoreIntegrationMethods, ICoreTwitterMethods, IMetricsMethods } from "../interfaces/ISnickerdoodleCore.js";
import { ISnickerdoodleCoreEvents } from "../interfaces/ISnickerdoodleCoreEvents.js";
import { AccountAddress, Age, BigNumberString, ChainId, CountryCode, DataWalletAddress, EmailAddressString, EVMContractAddress, FamilyName, Gender, GivenName, IpfsCID, LanguageCode, MarketplaceTag, Signature, UnixTimestamp, URLString } from "../primitives/index.js";
import { GetResultAsyncValueType, PopTuple } from "../types.js";
export declare type IProxyDiscordMethods = {
    [key in FunctionKeys<ICoreDiscordMethods>]: (...args: [...PopTuple<Parameters<ICoreDiscordMethods[key]>>]) => ResultAsync<GetResultAsyncValueType<ReturnType<ICoreDiscordMethods[key]>>, ProxyError>;
};
export declare type IProxyIntegrationMethods = {
    [key in Exclude<FunctionKeys<ICoreIntegrationMethods>, "grantPermissions" | "revokePermissions" | "requestPermissions" | "getPermissions">]: (...args: [...Parameters<ICoreIntegrationMethods[key]>]) => ResultAsync<GetResultAsyncValueType<ReturnType<ICoreIntegrationMethods[key]>>, ProxyError>;
} & {
    requestPermissions(...args: [
        ...PopTuple<Parameters<ICoreIntegrationMethods["requestPermissions"]>>
    ]): ResultAsync<GetResultAsyncValueType<ReturnType<ICoreIntegrationMethods["requestPermissions"]>>, ProxyError>;
    getPermissions(...args: [
        ...PopTuple<Parameters<ICoreIntegrationMethods["getPermissions"]>>
    ]): ResultAsync<GetResultAsyncValueType<ReturnType<ICoreIntegrationMethods["getPermissions"]>>, ProxyError>;
};
export declare type IProxyMetricsMethods = {
    [key in FunctionKeys<IMetricsMethods>]: (...args: [...PopTuple<Parameters<IMetricsMethods[key]>>]) => ResultAsync<GetResultAsyncValueType<ReturnType<IMetricsMethods[key]>>, ProxyError>;
};
export declare type IProxyTwitterMethods = {
    [key in FunctionKeys<ICoreTwitterMethods>]: (...args: [...PopTuple<Parameters<ICoreTwitterMethods[key]>>]) => ResultAsync<GetResultAsyncValueType<ReturnType<ICoreTwitterMethods[key]>>, ProxyError>;
};
export interface ISdlDataWallet {
    unlock(accountAddress: AccountAddress, signature: Signature, chain: EChain, languageCode?: LanguageCode): ResultAsync<void, ProxyError>;
    addAccount(accountAddress: AccountAddress, signature: Signature, chain: EChain, languageCode?: LanguageCode): ResultAsync<void, ProxyError>;
    getUnlockMessage(languageCode?: LanguageCode): ResultAsync<string, ProxyError>;
    getAge(): ResultAsync<Age | null, ProxyError>;
    setGivenName(givenName: GivenName): ResultAsync<void, ProxyError>;
    getGivenName(): ResultAsync<GivenName | null, ProxyError>;
    setFamilyName(familyName: FamilyName): ResultAsync<void, ProxyError>;
    getFamilyName(): ResultAsync<FamilyName | null, ProxyError>;
    setBirthday(birthday: UnixTimestamp): ResultAsync<void, ProxyError>;
    getBirthday(): ResultAsync<UnixTimestamp | null, ProxyError>;
    setGender(gender: Gender): ResultAsync<void, ProxyError>;
    getGender(): ResultAsync<Gender | null, ProxyError>;
    setEmail(email: EmailAddressString): ResultAsync<void, ProxyError>;
    getEmail(): ResultAsync<EmailAddressString | null, ProxyError>;
    setLocation(location: CountryCode): ResultAsync<void, ProxyError>;
    getLocation(): ResultAsync<CountryCode | null, ProxyError>;
    getAccounts(): ResultAsync<LinkedAccount[], ProxyError>;
    getTokenPrice(chainId: ChainId, address: TokenAddress | null, timestamp: UnixTimestamp): ResultAsync<number, ProxyError>;
    getTokenMarketData(ids: string[]): ResultAsync<TokenMarketData[], ProxyError>;
    getTokenInfo(chainId: ChainId, contractAddress: TokenAddress | null): ResultAsync<TokenInfo | null, ProxyError>;
    getAccountBalances(): ResultAsync<TokenBalance[], ProxyError>;
    getAccountNFTs(): ResultAsync<WalletNFT[], ProxyError>;
    closeTab(): ResultAsync<void, ProxyError>;
    getDataWalletAddress(): ResultAsync<DataWalletAddress | null, ProxyError>;
    getAcceptedInvitationsCID(): ResultAsync<Map<EVMContractAddress, IpfsCID>, ProxyError>;
    getAvailableInvitationsCID(): ResultAsync<Map<EVMContractAddress, IpfsCID>, ProxyError>;
    getInvitationMetadataByCID(ipfsCID: IpfsCID): ResultAsync<IOpenSeaMetadata, ProxyError>;
    getAgreementPermissions(consentContractAddres: EVMContractAddress): ResultAsync<EWalletDataType[], ProxyError>;
    getApplyDefaultPermissionsOption(): ResultAsync<boolean, ProxyError>;
    setApplyDefaultPermissionsOption(option: boolean): ResultAsync<void, ProxyError>;
    getDefaultPermissions(): ResultAsync<EWalletDataType[], ProxyError>;
    setDefaultPermissions(dataTypes: EWalletDataType[]): ResultAsync<void, ProxyError>;
    getScamFilterSettings(): ResultAsync<IScamFilterPreferences, ProxyError>;
    setScamFilterSettings(isScamFilterActive: boolean, showMessageEveryTime: boolean): ResultAsync<void, ProxyError>;
    setDefaultPermissionsToAll(): ResultAsync<void, ProxyError>;
    acceptInvitation(dataTypes: EWalletDataType[] | null, consentContractAddress: EVMContractAddress, tokenId?: BigNumberString, businessSignature?: Signature): ResultAsync<void, ProxyError>;
    rejectInvitation(consentContractAddress: EVMContractAddress, tokenId?: BigNumberString, businessSignature?: Signature, rejectUntil?: UnixTimestamp): any;
    leaveCohort(consentContractAddress: EVMContractAddress): ResultAsync<void, ProxyError>;
    unlinkAccount(accountAddress: AccountAddress, signature: Signature, chain: EChain, languageCode?: LanguageCode): ResultAsync<void, ProxyError>;
    checkInvitationStatus(consentAddress: EVMContractAddress, signature?: Signature, tokenId?: BigNumberString): ResultAsync<EInvitationStatus, ProxyError>;
    getConsentContractCID(consentAddress: EVMContractAddress): ResultAsync<IpfsCID, ProxyError>;
    getEarnedRewards(): ResultAsync<EarnedReward[], ProxyError>;
    getQueryStatusByQueryCID(queryCID: IpfsCID): ResultAsync<QueryStatus | null, ProxyError>;
    getSiteVisits(): ResultAsync<SiteVisit[], ProxyError>;
    getSiteVisitsMap(): ResultAsync<Map<URLString, number>, ProxyError>;
    getMarketplaceListingsByTag(pagingReq: PagingRequest, tag: MarketplaceTag, filterActive?: boolean): ResultAsync<PagedResponse<MarketplaceListing>, ProxyError>;
    getListingsTotalByTag(tag: MarketplaceTag): ResultAsync<number, ProxyError>;
    setDefaultReceivingAddress(receivingAddress: AccountAddress | null): ResultAsync<void, ProxyError>;
    setReceivingAddress(contractAddress: EVMContractAddress, receivingAddress: AccountAddress | null): ResultAsync<void, ProxyError>;
    getReceivingAddress(contractAddress?: EVMContractAddress): ResultAsync<AccountAddress, ProxyError>;
    getConsentCapacity(contractAddress: EVMContractAddress): ResultAsync<IConsentCapacity, ProxyError>;
    getPossibleRewards(contractAddresses: EVMContractAddress[], timeoutMs?: number): ResultAsync<Map<EVMContractAddress, PossibleReward[]>, ProxyError>;
    switchToTab(tabId: number): ResultAsync<void, ProxyError>;
    proxyType: ECoreProxyType;
    discord: IProxyDiscordMethods;
    integration: IProxyIntegrationMethods;
    twitter: IProxyTwitterMethods;
    metrics: IProxyMetricsMethods;
    events: ISnickerdoodleCoreEvents;
}
//# sourceMappingURL=ISdlDataWallet.d.ts.map